@@ -1,4 +1,4 @@
-/* $Id: bench_sock.c,v 1.5 1999/03/02 16:38:00 roca Exp $ */
+/* $Id: bench_sock.c,v 1.8 1999/05/11 11:59:26 roca Exp $ */
 /*
  * bench_sock.c
  *
@@ -9,7 +9,7 @@
  *	Socket access method routines.
  */
 /*
- * (c) Copyright 1998/1999 - V. Roca (vincent.roca@lip6.fr)
+ * Copyright (c) 1998/1999 - V.Roca (vincent.roca@lip6.fr) All rights reserved
  * This tool is provided as is, without any warranty.
  * Permission to use, copy and modify is provided for non commercial
  * purposes as long as this notice appears on all copies.
@@ -41,6 +41,7 @@ SockOpen (int	num)
 
 		if (!(sp = getservbyname(servername, "tcp"))) {
 			PRINT_OUT((stdout, "bench: don't know server name ""%s""\n", servername))
+			PRINT_OUT((stdout, "bench/benchd not registered in /etc/services or -p option forgotten\n"))
 			EXIT(num, 1);
 		}
 		sa.sin_port = htons(sp->s_port);
@@ -106,7 +107,7 @@ SockOpen (int	num)
 		}
 	}
 	value = SndbufMgmt(conn_fd, GET_SOCKBUF, 0);
-	PRINT_OUT((stdout, "CLIENT send socket :\t%d for conn %d\n", value, num))
+	PRINT_OUT((stdout, "CLIENT send socket :\t%d bytes for conn %d\n", value, num))
 }
 
 
@@ -141,6 +142,7 @@ SockSendMsg (int	num)
 		}
 	}
 #endif /* FAST_SYNC */
+	PrintStartTime(num);
 
 	gettimeofday(&time0, NULL);
 	time1 = time0;
@@ -168,7 +170,7 @@ SockSendMsg (int	num)
 			mtraceon();
 #endif /* MTRACE */
 		if (mode == RTT_MODE && raw) {
-			/* we need a detailled avaluation of RTT */
+			/* we need a detailled evaluation of RTT */
 			gettimeofday(&send_time, NULL);
 		}
 		if (udp) {
@@ -309,6 +311,7 @@ end_test:
 	}
 #endif /* FAST_SYNC */
 	EndStats();
+	PrintEndTime(num);
 }
 
 
