@@ -1,4 +1,4 @@
-/* $Id: benchd.c,v 1.4 1999/03/02 16:38:04 roca Exp $ */
+/* $Id: benchd.c,v 1.6 1999/05/11 11:59:27 roca Exp $ */
 /*
  * benchd.c
  *
@@ -8,7 +8,7 @@
  *	Server part of the performance evaluation tool.
  */
 /*
- * (c) Copyright 1998/1999 - V. Roca (vincent.roca@lip6.fr)
+ * Copyright (c) 1998/1999 - V.Roca (vincent.roca@lip6.fr) All rights reserved
  * This tool is provided as is, without any warranty.
  * Permission to use, copy and modify is provided for non commercial
  * purposes as long as this notice appears on all copies.
@@ -155,6 +155,7 @@ void
 Interrupted (void)
 {
 	EndStats();
+	PrintEndTime(connex);
 	exit(0);
 }
 
@@ -226,6 +227,7 @@ sync_setup (void)
 			else {
 				if (!(sp = getservbyname("benchd_sync", "tcp"))) {
 					PRINT_ERR((stderr, "benchd sync: don't know servername ""benchd_sync""\n"))
+					PRINT_OUT((stdout, "bench/benchd not registered in /etc/services or -p option forgotten\n"))
 					exit(-1);
 				}
 				sa.sin_port = htons(sp->s_port);
@@ -358,7 +360,7 @@ sync_start (void)
 	sscanf(syncbuf, SYNC_FORMAT, &lgthmsg, &nbconn);
 	PRINT_OUT((stdout, "====== start sync ======\n"))
 	PRINT_OUT((stdout, "SERVER_SYNC connect :\t\t%d\n", nbconn))
-	PRINT_OUT((stdout, "SERVER_SYNC length of msg :\t%d\n", lgthmsg))
+	PRINT_OUT((stdout, "SERVER_SYNC length of msg :\t%d bytes\n", lgthmsg))
 	/*
 	 * Run the CPU usage tool.
 	 */
